@@ -1,3 +1,4 @@
+from pydantic import BaseModel
 from rath.operation import Operation
 from rath.links.parsing import ParsingLink
 
@@ -5,18 +6,18 @@ from rath.links.parsing import ParsingLink
 class DictingLink(ParsingLink):
     def parse(self, operation: Operation) -> Operation:
         shrinked_variables = {
-            key: var.dict()
+            key: dict(var)
             for key, var in operation.variables.items()
-            if hasattr(var, "dict")
+            if isinstance(var, BaseModel)
         }
         operation.variables.update(shrinked_variables)
         return operation
 
     async def aparse(self, operation: Operation) -> Operation:
         shrinked_variables = {
-            key: var.dict()
+            key: dict(var)
             for key, var in operation.variables.items()
-            if hasattr(var, "dict")
+            if isinstance(var, BaseModel)
         }
         operation.variables.update(shrinked_variables)
         return operation
